from abc import ABC
from dataclasses import dataclass, field
from datetime import datetime
from enum import Enum
from typing import Dict, List

from _qwak_proto.qwak.audience.v1.audience_pb2 import (
    AudienceRoutesEntry as AudienceProto,
)
from _qwak_proto.qwak.audience.v1.audience_pb2 import Route as RouteProto
from _qwak_proto.qwak.auto_scaling.v1.auto_scaling_pb2 import (
    AutoScalingConfig as AutoScalingProto,
)
from _qwak_proto.qwak.deployment.deployment_pb2 import (
    DeploymentDetails as DeploymentProto,
)
from _qwak_proto.qwak.deployment.deployment_pb2 import (
    RealTimeConfig as RealTimeConfigProto,
)
from _qwak_proto.qwak.deployment.deployment_pb2 import (
    ServingStrategy as ServingStrategyProto,
)
from _qwak_proto.qwak.deployment.deployment_pb2 import StreamConfig as StreamConfigProto


@dataclass
class TrafficSpec:
    percentage: int = field(default=None)
    is_shadow: bool = field(default=None)


@dataclass
class Variation:
    name: str = field(default=None)
    environment_id: str = field(default=None)
    traffic_spec: TrafficSpec = field(default=None)


@dataclass
class Route:
    variation_name: str = field(default=None)
    weight: int = field(default=None)
    shadow: bool = field(default=None)
    model_id: str = field(default=None)
    environment_id: str = field(default=None)
    audience_id: str = field(default=None)


@dataclass
class AudienceRoute:
    audience_id: str = field(default=None)
    audience_name: str = field(default=None)
    routes: List[Route] = field(default_factory=list)
    order: int = field(default=None)


@dataclass
class EnvironmentAudienceRoute(AudienceRoute):
    environment_id: str = field(default=None)

    @staticmethod
    def from_proto(environment_id: str, proto: AudienceProto):
        return EnvironmentAudienceRoute(
            audience_id=proto.audience_id,
            audience_name=proto.audience_name,
            routes=Deployment.parse_routes(proto.routes),
            order=proto.order,
            environment_id=environment_id,
        )


class Metric(Enum):
    NOT_VALID = 0
    CPU = 1
    MEMORY = 2
    LATENCY = 3
    GPU = 4
    ERROR_RATE = 5
    THROUGHPUT = 6


class Aggregation(Enum):
    NOT_VALID = 0
    MIN = 1
    MAX = 2
    AVERAGE = 3
    SUM = 4


@dataclass
class QuerySpec:
    metric: Metric = field(default=None)
    aggregation: Aggregation = field(default=None)
    time_period: int = field(default=None)
    error_code: str = field(default=None)


class Triggers(ABC):
    pass


@dataclass
class PrometheusTrigger(Triggers):
    query_spec: QuerySpec = field(default=None)
    threshold: int = field(default=None)


@dataclass
class AutoScalingConfig:
    min_replica_count: int = field(default=None)
    max_replica_count: int = field(default=None)
    pooling_interval: int = field(default=None)
    cool_down_period: int = field(default=None)
    triggers: List[Triggers] = field(default_factory=list)


@dataclass
class TrafficConfig:
    selected_variation_name: str = field(default=None)
    variations: List[Variation] = field(default_factory=list)
    audiences: List[AudienceRoute] = field(default_factory=list)
    fallback_variation: str = field(default=None)


class ServingConfig(ABC):
    pass


@dataclass
class RealTimeConfig(ServingConfig):
    traffic_config: TrafficConfig = field(default=None)
    autoscaling_config: AutoScalingConfig = field(default=None)


@dataclass
class BatchConfig(ServingConfig):
    pass


class AutoOffSet(Enum):
    UNKNOWN = 0
    EARLIEST = 1
    LATEST = 2


@dataclass
class Consumer:
    bootstrap_server: List[str] = field(default_factory=list)
    topic: str = field(default=None)
    group: str = field(default=None)
    timeout: int = field(default=None)
    auto_offset: AutoOffSet = field(default=None)
    max_batch_size: int = field(default=None)
    max_poll_latency: float = field(default=None)


class Compression(Enum):
    UNKNOWN = 0
    UNCOMPRESSED = 1
    GZIP = 2
    SNAPPY = 3
    LZ4 = 4
    ZSTD = 5


@dataclass
class Producer:
    bootstrap_server: List[str] = field(default_factory=list)
    topic: str = field(default=None)
    compression: Compression = field(default=None)


@dataclass
class KafkaConfig:
    consumer: Consumer = field(default=None)
    producer: Producer = field(default=None)
    workers: int = field(default=None)


@dataclass
class StreamConfig(ServingConfig):
    kafka: KafkaConfig = field(default=None)


class BuildStatus(Enum):
    INVALID = 0
    IN_PROGRESS = 1
    SUCCESSFUL = 2
    FAILED = 3
    REMOTE_BUILD_INITIALIZING = 4
    REMOTE_BUILD_CANCELLED = 5
    REMOTE_BUILD_TIMED_OUT = 6
    REMOTE_BUILD_UNKNOWN = 7
    SYNCING_ENVIRONMENTS = 8
    FINISHED_SYNCING = 9


class MemoryUnit(Enum):
    UNKNOWN = 0
    MIB = 1
    GIB = 2


class KubeDeploymentType(Enum):
    UNDEFINED = 0
    ONLINE = 1
    STREAM = 2
    BATCH = 3


class GpuType(Enum):
    INVALID_GPU = 0
    ONLINE = 1
    STREAM = 2
    BATCH = 3


@dataclass
class Deployment:
    build_id: str = field(default=None)
    number_of_pods: int = field(default=None)
    cpu_fraction: float = field(default=None)
    memory_amount: int = field(default=None)
    memory_units: MemoryUnit = field(default=MemoryUnit.UNKNOWN)
    number_of_workers: int = field(default=None)
    http_request_timeout_ms: int = field(default=None)
    kube_deployment_type: KubeDeploymentType = field(
        default=KubeDeploymentType.UNDEFINED
    )
    serving_config: ServingConfig = field(default=None)
    variation: Variation = field(default=None)
    custom_iam_role_arn: str = field(default=None)
    max_batch_size: int = field(default=None)
    gpu_type: GpuType = field(default=GpuType.INVALID_GPU)
    gpu_amount: int = field(default=None)
    environment_id: str = field(default=None)
    available_replicas: int = field(default=None)
    deployment_process_timeout_limit: int = field(default=None)
    daemon_mode: bool = field(default=None)
    purchase_option: str = field(default=None)
    environment_variables: Dict[str, str] = field(default_factory=dict)
    last_deployed: datetime = field(default=datetime.now())

    @staticmethod
    def parse_routes(proto: List[RouteProto]) -> List[Route]:
        routes = []
        for proto_route in proto:
            route = Route(
                variation_name=proto_route.variation_name,
                weight=proto_route.weight,
                shadow=proto_route.shadow,
                model_id=proto_route.model_id,
                environment_id=proto_route.environment_id,
                audience_id=proto_route.audience_id,
            )
            routes.append(route)
        return routes

    @staticmethod
    def parse_audience_routes(proto: List[RouteProto]) -> List[AudienceRoute]:
        routes = []
        for proto_route in proto:
            route = AudienceRoute(
                audience_id=proto_route.audience_id,
                audience_name=proto_route.audience_name,
                routes=Deployment.parse_routes(proto_route.routes),
                order=proto_route.order,
            )
            routes.append(route)
        return routes

    @staticmethod
    def parse_autoscaling(proto: AutoScalingProto) -> AutoScalingConfig:
        triggers = []
        for proto_trigger in proto.triggers.triggers:
            trigger = PrometheusTrigger(
                query_spec=QuerySpec(
                    metric=Metric(
                        proto_trigger.prometheus_trigger.query_spec.metric_type
                    ),
                    aggregation=Aggregation(
                        proto_trigger.prometheus_trigger.query_spec.aggregation_type
                    ),
                    time_period=proto_trigger.prometheus_trigger.query_spec.time_period,
                    error_code=proto_trigger.prometheus_trigger.query_spec.status_code,
                ),
                threshold=proto_trigger.prometheus_trigger.threshold,
            )
            triggers.append(trigger)
        return AutoScalingConfig(
            min_replica_count=proto.min_replica_count,
            max_replica_count=proto.max_replica_count,
            pooling_interval=proto.polling_interval,
            cool_down_period=proto.cool_down_period,
            triggers=triggers,
        )

    @staticmethod
    def parse_realtime_config(proto: RealTimeConfigProto) -> RealTimeConfig:
        variations = []
        for proto_variation in proto.traffic_config.variations:
            variation = Variation(
                name=proto_variation.name,
                environment_id=proto_variation.environment_id,
                traffic_spec=TrafficSpec(
                    percentage=proto_variation.traffic.percentage,
                    is_shadow=proto_variation.traffic.is_shadow,
                ),
            )
            variations.append(variation)
        audiences = []
        for proto_audience in proto.traffic_config.audience_routes_entries:
            audience = AudienceRoute(
                audience_id=proto_audience.audience_id,
                audience_name=proto_audience.audience_name,
                routes=Deployment.parse_routes(proto_audience.routes),
                order=proto_audience.order,
            )
            audiences.append(audience)

        autoscaling = Deployment.parse_autoscaling(proto.auto_scaling_config)
        return RealTimeConfig(
            traffic_config=TrafficConfig(
                variations=variations,
                audiences=audiences,
                fallback_variation=proto.traffic_config.fallback_variation,
            ),
            autoscaling_config=autoscaling,
        )

    @staticmethod
    def parse_streaming_config(proto_config: StreamConfigProto) -> StreamConfig:
        return StreamConfig(
            kafka=KafkaConfig(
                consumer=Consumer(
                    bootstrap_server=list(proto_config.kafka.consumer.bootstrap_server),
                    topic=proto_config.kafka.consumer.topic,
                    group=proto_config.kafka.consumer.group,
                    timeout=proto_config.kafka.consumer.timeout,
                    auto_offset=(
                        AutoOffSet(proto_config.kafka.consumer.auto_offset_type)
                        if proto_config.kafka.consumer.auto_offset_type
                        else None
                    ),
                    max_batch_size=proto_config.kafka.consumer.max_batch_size,
                    max_poll_latency=proto_config.kafka.consumer.max_poll_latency,
                ),
                producer=Producer(
                    bootstrap_server=list(proto_config.kafka.producer.bootstrap_server),
                    topic=proto_config.kafka.producer.topic,
                    compression=(
                        Compression(proto_config.kafka.producer.compression_type)
                        if proto_config.kafka.producer.compression_type
                        else None
                    ),
                ),
                workers=proto_config.kafka.workers,
            )
        )

    @staticmethod
    def parse_serving_strategy(proto: ServingStrategyProto) -> ServingConfig:
        which = proto.WhichOneof("Strategy")
        if which == "realtime_config":
            return Deployment.parse_realtime_config(proto.realtime_config)
        elif which == "batch_config":
            return BatchConfig()
        elif which == "stream_config":
            return Deployment.parse_streaming_config(proto.stream_config)
        else:
            raise ValueError(f"Unknown serving strategy: {which}")

    @staticmethod
    def from_proto(proto: DeploymentProto):
        variation = Variation(
            name=proto.variation.name,
            environment_id=proto.variation.environment_id,
            traffic_spec=TrafficSpec(
                percentage=proto.variation.traffic.percentage,
                is_shadow=proto.variation.traffic.is_shadow,
            ),
        )
        return Deployment(
            build_id=proto.build_id,
            number_of_pods=proto.number_of_pods,
            cpu_fraction=proto.cpu_fraction,
            memory_amount=proto.memory_amount,
            memory_units=MemoryUnit(proto.memory_units),
            number_of_workers=proto.number_of_workers,
            http_request_timeout_ms=proto.http_request_timeout_ms,
            kube_deployment_type=KubeDeploymentType(proto.kube_deployment_type),
            serving_config=Deployment.parse_serving_strategy(proto.serving_strategy),
            variation=variation,
            custom_iam_role_arn=proto.custom_iam_role_arn,
            max_batch_size=proto.max_batch_size,
            gpu_type=GpuType(proto.gpu_type),
            gpu_amount=proto.gpu_amount,
            environment_id=proto.environment_id,
            available_replicas=proto.available_replicas,
            daemon_mode=bool(proto.daemon_mode.value),
            deployment_process_timeout_limit=proto.deployment_process_timeout_limit,
            purchase_option=proto.purchase_option,
            environment_variables=dict(proto.environment_variables),
            last_deployed=datetime.fromtimestamp(
                proto.last_deployed.seconds + proto.last_deployed.nanos / 1e9
            ),
        )



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.service_discovery import service_discovery_location_service_pb2 as qwak_dot_service__discovery_dot_service__discovery__location__service__pb2


class LocationDiscoveryServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetOfflineServingUrl = channel.unary_unary(
                '/qwak.service_discovery.location.v0.LocationDiscoveryService/GetOfflineServingUrl',
                request_serializer=qwak_dot_service__discovery_dot_service__discovery__location__service__pb2.GetServingUrlRequest.SerializeToString,
                response_deserializer=qwak_dot_service__discovery_dot_service__discovery__location__service__pb2.GetServingUrlRequestResponse.FromString,
                )
        self.GetDistributionManagerUrl = channel.unary_unary(
                '/qwak.service_discovery.location.v0.LocationDiscoveryService/GetDistributionManagerUrl',
                request_serializer=qwak_dot_service__discovery_dot_service__discovery__location__service__pb2.GetServingUrlRequest.SerializeToString,
                response_deserializer=qwak_dot_service__discovery_dot_service__discovery__location__service__pb2.GetServingUrlRequestResponse.FromString,
                )
        self.GetAnalyticsEngineUrl = channel.unary_unary(
                '/qwak.service_discovery.location.v0.LocationDiscoveryService/GetAnalyticsEngineUrl',
                request_serializer=qwak_dot_service__discovery_dot_service__discovery__location__service__pb2.GetServingUrlRequest.SerializeToString,
                response_deserializer=qwak_dot_service__discovery_dot_service__discovery__location__service__pb2.GetServingUrlRequestResponse.FromString,
                )
        self.GetMetricsGatewayUrl = channel.unary_unary(
                '/qwak.service_discovery.location.v0.LocationDiscoveryService/GetMetricsGatewayUrl',
                request_serializer=qwak_dot_service__discovery_dot_service__discovery__location__service__pb2.GetServingUrlRequest.SerializeToString,
                response_deserializer=qwak_dot_service__discovery_dot_service__discovery__location__service__pb2.GetServingUrlRequestResponse.FromString,
                )
        self.GetFeaturesOperatorUrl = channel.unary_unary(
                '/qwak.service_discovery.location.v0.LocationDiscoveryService/GetFeaturesOperatorUrl',
                request_serializer=qwak_dot_service__discovery_dot_service__discovery__location__service__pb2.GetServingUrlRequest.SerializeToString,
                response_deserializer=qwak_dot_service__discovery_dot_service__discovery__location__service__pb2.GetServingUrlRequestResponse.FromString,
                )
        self.GetHostingGatewayUrl = channel.unary_unary(
                '/qwak.service_discovery.location.v0.LocationDiscoveryService/GetHostingGatewayUrl',
                request_serializer=qwak_dot_service__discovery_dot_service__discovery__location__service__pb2.GetServingUrlRequest.SerializeToString,
                response_deserializer=qwak_dot_service__discovery_dot_service__discovery__location__service__pb2.GetServingUrlRequestResponse.FromString,
                )


class LocationDiscoveryServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetOfflineServingUrl(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDistributionManagerUrl(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAnalyticsEngineUrl(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMetricsGatewayUrl(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeaturesOperatorUrl(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetHostingGatewayUrl(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_LocationDiscoveryServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetOfflineServingUrl': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOfflineServingUrl,
                    request_deserializer=qwak_dot_service__discovery_dot_service__discovery__location__service__pb2.GetServingUrlRequest.FromString,
                    response_serializer=qwak_dot_service__discovery_dot_service__discovery__location__service__pb2.GetServingUrlRequestResponse.SerializeToString,
            ),
            'GetDistributionManagerUrl': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDistributionManagerUrl,
                    request_deserializer=qwak_dot_service__discovery_dot_service__discovery__location__service__pb2.GetServingUrlRequest.FromString,
                    response_serializer=qwak_dot_service__discovery_dot_service__discovery__location__service__pb2.GetServingUrlRequestResponse.SerializeToString,
            ),
            'GetAnalyticsEngineUrl': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAnalyticsEngineUrl,
                    request_deserializer=qwak_dot_service__discovery_dot_service__discovery__location__service__pb2.GetServingUrlRequest.FromString,
                    response_serializer=qwak_dot_service__discovery_dot_service__discovery__location__service__pb2.GetServingUrlRequestResponse.SerializeToString,
            ),
            'GetMetricsGatewayUrl': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMetricsGatewayUrl,
                    request_deserializer=qwak_dot_service__discovery_dot_service__discovery__location__service__pb2.GetServingUrlRequest.FromString,
                    response_serializer=qwak_dot_service__discovery_dot_service__discovery__location__service__pb2.GetServingUrlRequestResponse.SerializeToString,
            ),
            'GetFeaturesOperatorUrl': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeaturesOperatorUrl,
                    request_deserializer=qwak_dot_service__discovery_dot_service__discovery__location__service__pb2.GetServingUrlRequest.FromString,
                    response_serializer=qwak_dot_service__discovery_dot_service__discovery__location__service__pb2.GetServingUrlRequestResponse.SerializeToString,
            ),
            'GetHostingGatewayUrl': grpc.unary_unary_rpc_method_handler(
                    servicer.GetHostingGatewayUrl,
                    request_deserializer=qwak_dot_service__discovery_dot_service__discovery__location__service__pb2.GetServingUrlRequest.FromString,
                    response_serializer=qwak_dot_service__discovery_dot_service__discovery__location__service__pb2.GetServingUrlRequestResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.service_discovery.location.v0.LocationDiscoveryService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class LocationDiscoveryService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetOfflineServingUrl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.service_discovery.location.v0.LocationDiscoveryService/GetOfflineServingUrl',
            qwak_dot_service__discovery_dot_service__discovery__location__service__pb2.GetServingUrlRequest.SerializeToString,
            qwak_dot_service__discovery_dot_service__discovery__location__service__pb2.GetServingUrlRequestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDistributionManagerUrl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.service_discovery.location.v0.LocationDiscoveryService/GetDistributionManagerUrl',
            qwak_dot_service__discovery_dot_service__discovery__location__service__pb2.GetServingUrlRequest.SerializeToString,
            qwak_dot_service__discovery_dot_service__discovery__location__service__pb2.GetServingUrlRequestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAnalyticsEngineUrl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.service_discovery.location.v0.LocationDiscoveryService/GetAnalyticsEngineUrl',
            qwak_dot_service__discovery_dot_service__discovery__location__service__pb2.GetServingUrlRequest.SerializeToString,
            qwak_dot_service__discovery_dot_service__discovery__location__service__pb2.GetServingUrlRequestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMetricsGatewayUrl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.service_discovery.location.v0.LocationDiscoveryService/GetMetricsGatewayUrl',
            qwak_dot_service__discovery_dot_service__discovery__location__service__pb2.GetServingUrlRequest.SerializeToString,
            qwak_dot_service__discovery_dot_service__discovery__location__service__pb2.GetServingUrlRequestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFeaturesOperatorUrl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.service_discovery.location.v0.LocationDiscoveryService/GetFeaturesOperatorUrl',
            qwak_dot_service__discovery_dot_service__discovery__location__service__pb2.GetServingUrlRequest.SerializeToString,
            qwak_dot_service__discovery_dot_service__discovery__location__service__pb2.GetServingUrlRequestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetHostingGatewayUrl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.service_discovery.location.v0.LocationDiscoveryService/GetHostingGatewayUrl',
            qwak_dot_service__discovery_dot_service__discovery__location__service__pb2.GetServingUrlRequest.SerializeToString,
            qwak_dot_service__discovery_dot_service__discovery__location__service__pb2.GetServingUrlRequestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.build_settings.build_settings_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class SaveBuildSettingsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_SETTINGS_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    @property
    def build_settings(self) -> qwak.build_settings.build_settings_pb2.BuildSettings: ...
    @property
    def environment_id(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        build_settings: qwak.build_settings.build_settings_pb2.BuildSettings | None = ...,
        environment_id: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["build_settings", b"build_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_settings", b"build_settings", "environment_id", b"environment_id"]) -> None: ...

global___SaveBuildSettingsRequest = SaveBuildSettingsRequest

class SaveBuildSettingsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_SETTINGS_ID_FIELD_NUMBER: builtins.int
    @property
    def build_settings_id(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        build_settings_id: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_settings_id", b"build_settings_id"]) -> None: ...

global___SaveBuildSettingsResponse = SaveBuildSettingsResponse

class GetBuildSettingsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    environment_id: builtins.str
    def __init__(
        self,
        *,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id"]) -> None: ...

global___GetBuildSettingsRequest = GetBuildSettingsRequest

class GetBuildSettingsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_SETTINGS_FIELD_NUMBER: builtins.int
    @property
    def build_settings(self) -> qwak.build_settings.build_settings_pb2.BuildSettings: ...
    def __init__(
        self,
        *,
        build_settings: qwak.build_settings.build_settings_pb2.BuildSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["build_settings", b"build_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_settings", b"build_settings"]) -> None: ...

global___GetBuildSettingsResponse = GetBuildSettingsResponse

class DeleteBuildSettingsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    environment_id: builtins.str
    def __init__(
        self,
        *,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id"]) -> None: ...

global___DeleteBuildSettingsRequest = DeleteBuildSettingsRequest

class DeleteBuildSettingsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteBuildSettingsResponse = DeleteBuildSettingsResponse



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.builds import builds_pb2 as qwak_dot_builds_dot_builds__pb2


class BuildsManagementServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.RegisterBuild = channel.unary_unary(
                '/qwak.builds.management.BuildsManagementService/RegisterBuild',
                request_serializer=qwak_dot_builds_dot_builds__pb2.RegisterBuildRequest.SerializeToString,
                response_deserializer=qwak_dot_builds_dot_builds__pb2.RegisterBuildResponse.FromString,
                )
        self.UpdateBuildStatus = channel.unary_unary(
                '/qwak.builds.management.BuildsManagementService/UpdateBuildStatus',
                request_serializer=qwak_dot_builds_dot_builds__pb2.UpdateBuildStatusRequest.SerializeToString,
                response_deserializer=qwak_dot_builds_dot_builds__pb2.UpdateBuildStatusResponse.FromString,
                )
        self.RegisterModelSchema = channel.unary_unary(
                '/qwak.builds.management.BuildsManagementService/RegisterModelSchema',
                request_serializer=qwak_dot_builds_dot_builds__pb2.RegisterModelSchemaRequest.SerializeToString,
                response_deserializer=qwak_dot_builds_dot_builds__pb2.RegisterModelSchemaResponse.FromString,
                )
        self.RegisterExperimentTrackingValues = channel.unary_unary(
                '/qwak.builds.management.BuildsManagementService/RegisterExperimentTrackingValues',
                request_serializer=qwak_dot_builds_dot_builds__pb2.RegisterExperimentTrackingValuesRequest.SerializeToString,
                response_deserializer=qwak_dot_builds_dot_builds__pb2.RegisterExperimentTrackingValuesResponse.FromString,
                )
        self.GetBuild = channel.unary_unary(
                '/qwak.builds.management.BuildsManagementService/GetBuild',
                request_serializer=qwak_dot_builds_dot_builds__pb2.GetBuildRequest.SerializeToString,
                response_deserializer=qwak_dot_builds_dot_builds__pb2.GetBuildResponse.FromString,
                )
        self.ListBuilds = channel.unary_unary(
                '/qwak.builds.management.BuildsManagementService/ListBuilds',
                request_serializer=qwak_dot_builds_dot_builds__pb2.ListBuildsRequest.SerializeToString,
                response_deserializer=qwak_dot_builds_dot_builds__pb2.ListBuildsResponse.FromString,
                )


class BuildsManagementServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def RegisterBuild(self, request, context):
        """Register a Qwak build
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateBuildStatus(self, request, context):
        """Update Build Status
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterModelSchema(self, request, context):
        """Register model schema (interface) as part of a build
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterExperimentTrackingValues(self, request, context):
        """Register Qwak metrics and params
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBuild(self, request, context):
        """Get build
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListBuilds(self, request, context):
        """List registered builds for the given branch
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_BuildsManagementServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'RegisterBuild': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterBuild,
                    request_deserializer=qwak_dot_builds_dot_builds__pb2.RegisterBuildRequest.FromString,
                    response_serializer=qwak_dot_builds_dot_builds__pb2.RegisterBuildResponse.SerializeToString,
            ),
            'UpdateBuildStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateBuildStatus,
                    request_deserializer=qwak_dot_builds_dot_builds__pb2.UpdateBuildStatusRequest.FromString,
                    response_serializer=qwak_dot_builds_dot_builds__pb2.UpdateBuildStatusResponse.SerializeToString,
            ),
            'RegisterModelSchema': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterModelSchema,
                    request_deserializer=qwak_dot_builds_dot_builds__pb2.RegisterModelSchemaRequest.FromString,
                    response_serializer=qwak_dot_builds_dot_builds__pb2.RegisterModelSchemaResponse.SerializeToString,
            ),
            'RegisterExperimentTrackingValues': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterExperimentTrackingValues,
                    request_deserializer=qwak_dot_builds_dot_builds__pb2.RegisterExperimentTrackingValuesRequest.FromString,
                    response_serializer=qwak_dot_builds_dot_builds__pb2.RegisterExperimentTrackingValuesResponse.SerializeToString,
            ),
            'GetBuild': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBuild,
                    request_deserializer=qwak_dot_builds_dot_builds__pb2.GetBuildRequest.FromString,
                    response_serializer=qwak_dot_builds_dot_builds__pb2.GetBuildResponse.SerializeToString,
            ),
            'ListBuilds': grpc.unary_unary_rpc_method_handler(
                    servicer.ListBuilds,
                    request_deserializer=qwak_dot_builds_dot_builds__pb2.ListBuildsRequest.FromString,
                    response_serializer=qwak_dot_builds_dot_builds__pb2.ListBuildsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.builds.management.BuildsManagementService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class BuildsManagementService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def RegisterBuild(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.builds.management.BuildsManagementService/RegisterBuild',
            qwak_dot_builds_dot_builds__pb2.RegisterBuildRequest.SerializeToString,
            qwak_dot_builds_dot_builds__pb2.RegisterBuildResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateBuildStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.builds.management.BuildsManagementService/UpdateBuildStatus',
            qwak_dot_builds_dot_builds__pb2.UpdateBuildStatusRequest.SerializeToString,
            qwak_dot_builds_dot_builds__pb2.UpdateBuildStatusResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterModelSchema(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.builds.management.BuildsManagementService/RegisterModelSchema',
            qwak_dot_builds_dot_builds__pb2.RegisterModelSchemaRequest.SerializeToString,
            qwak_dot_builds_dot_builds__pb2.RegisterModelSchemaResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterExperimentTrackingValues(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.builds.management.BuildsManagementService/RegisterExperimentTrackingValues',
            qwak_dot_builds_dot_builds__pb2.RegisterExperimentTrackingValuesRequest.SerializeToString,
            qwak_dot_builds_dot_builds__pb2.RegisterExperimentTrackingValuesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBuild(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.builds.management.BuildsManagementService/GetBuild',
            qwak_dot_builds_dot_builds__pb2.GetBuildRequest.SerializeToString,
            qwak_dot_builds_dot_builds__pb2.GetBuildResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListBuilds(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.builds.management.BuildsManagementService/ListBuilds',
            qwak_dot_builds_dot_builds__pb2.ListBuildsRequest.SerializeToString,
            qwak_dot_builds_dot_builds__pb2.ListBuildsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/service_discovery/service_discovery_location.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7qwak/service_discovery/service_discovery_location.proto\x12\"qwak.service_discovery.location.v0\"w\n\x19ServiceLocationDescriptor\x12\x13\n\x0bservice_url\x18\x01 \x01(\t\x12\x45\n\x08location\x18\x02 \x01(\x0b\x32\x33.qwak.service_discovery.location.v0.ServiceLocation\"\x99\x01\n\x0fServiceLocation\x12\x38\n\x04\x63ore\x18\x01 \x01(\x0b\x32(.qwak.service_discovery.location.v0.CoreH\x00\x12\x38\n\x04\x65\x64ge\x18\x02 \x01(\x0b\x32(.qwak.service_discovery.location.v0.EdgeH\x00\x42\x12\n\x10service_location\"\x06\n\x04\x43ore\"\x06\n\x04\x45\x64geB-\n)com.qwak.ai.service_discovery.location.v0P\x01\x62\x06proto3')



_SERVICELOCATIONDESCRIPTOR = DESCRIPTOR.message_types_by_name['ServiceLocationDescriptor']
_SERVICELOCATION = DESCRIPTOR.message_types_by_name['ServiceLocation']
_CORE = DESCRIPTOR.message_types_by_name['Core']
_EDGE = DESCRIPTOR.message_types_by_name['Edge']
ServiceLocationDescriptor = _reflection.GeneratedProtocolMessageType('ServiceLocationDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _SERVICELOCATIONDESCRIPTOR,
  '__module__' : 'qwak.service_discovery.service_discovery_location_pb2'
  # @@protoc_insertion_point(class_scope:qwak.service_discovery.location.v0.ServiceLocationDescriptor)
  })
_sym_db.RegisterMessage(ServiceLocationDescriptor)

ServiceLocation = _reflection.GeneratedProtocolMessageType('ServiceLocation', (_message.Message,), {
  'DESCRIPTOR' : _SERVICELOCATION,
  '__module__' : 'qwak.service_discovery.service_discovery_location_pb2'
  # @@protoc_insertion_point(class_scope:qwak.service_discovery.location.v0.ServiceLocation)
  })
_sym_db.RegisterMessage(ServiceLocation)

Core = _reflection.GeneratedProtocolMessageType('Core', (_message.Message,), {
  'DESCRIPTOR' : _CORE,
  '__module__' : 'qwak.service_discovery.service_discovery_location_pb2'
  # @@protoc_insertion_point(class_scope:qwak.service_discovery.location.v0.Core)
  })
_sym_db.RegisterMessage(Core)

Edge = _reflection.GeneratedProtocolMessageType('Edge', (_message.Message,), {
  'DESCRIPTOR' : _EDGE,
  '__module__' : 'qwak.service_discovery.service_discovery_location_pb2'
  # @@protoc_insertion_point(class_scope:qwak.service_discovery.location.v0.Edge)
  })
_sym_db.RegisterMessage(Edge)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.qwak.ai.service_discovery.location.v0P\001'
  _SERVICELOCATIONDESCRIPTOR._serialized_start=95
  _SERVICELOCATIONDESCRIPTOR._serialized_end=214
  _SERVICELOCATION._serialized_start=217
  _SERVICELOCATION._serialized_end=370
  _CORE._serialized_start=372
  _CORE._serialized_end=378
  _EDGE._serialized_start=380
  _EDGE._serialized_end=386
# @@protoc_insertion_point(module_scope)



import uuid

from _qwak_proto.qwak.deployment.alert_service_pb2 import (
    ApplyNotificationChannelRequest,
    ApplyNotificationChannelResponse,
    DeleteNotificationChannelRequest,
    DeleteNotificationChannelResponse,
    GetNotificationChannelDetailsListRequest,
    GetNotificationChannelDetailsListResponse,
)
from _qwak_proto.qwak.deployment.alert_service_pb2_grpc import (
    AlertManagementServiceServicer,
)
from qwak_services_mock.mocks.utils.exception_handlers import raise_internal_grpc_error


class AlertManagerServiceApiMock(AlertManagementServiceServicer):
    def __init__(self):
        super(AlertManagerServiceApiMock, self).__init__()
        self.notification_channels = dict()

    def ApplyNotificationChannel(
        self, request: ApplyNotificationChannelRequest, context
    ) -> ApplyNotificationChannelResponse:
        """Channels to add or update"""
        try:
            request.notification_channel.notification_channel_id = str(uuid.uuid4())
            self.notification_channels[
                request.notification_channel.notification_channel_id
            ] = request.notification_channel
            return ApplyNotificationChannelResponse()
        except Exception as e:
            raise_internal_grpc_error(context, e)

    def DeleteNotificationChannel(
        self, request: DeleteNotificationChannelRequest, context
    ) -> DeleteNotificationChannelResponse:
        """Delete notification channel"""
        try:
            del self.notification_channels[request.notification_channel_id]
            return DeleteNotificationChannelResponse()
        except Exception as e:
            raise_internal_grpc_error(context, e)

    def GetNotificationChannelDetailsList(
        self, request: GetNotificationChannelDetailsListRequest, context
    ) -> GetNotificationChannelDetailsListResponse:
        """Get Full Details for channels"""
        try:
            return GetNotificationChannelDetailsListResponse(
                notification_channels=list(self.notification_channels.values())
            )
        except Exception as e:
            raise_internal_grpc_error(context, e)



from dataclasses import dataclass, field
from enum import Enum

from _qwak_proto.qwak.file_versioning.file_versioning_pb2 import (
    FileTagFilter as FileTagFilterProto,
)


class FileTagFilerType(Enum):
    FILE_TAG_FILTER_TYPE_INVALID = 0
    FILE_TAG_FILTER_TYPE_CONTAINS = 1
    FILE_TAG_FILTER_TYPE_PREFIX = 2


@dataclass
class FileTagFilter:
    value: str = field(default=None)
    type: FileTagFilerType = field(
        default=FileTagFilerType.FILE_TAG_FILTER_TYPE_INVALID
    )

    def to_proto(self):
        if self.type is FileTagFilerType.FILE_TAG_FILTER_TYPE_CONTAINS:
            return FileTagFilterProto(
                tag_contains=self.value,
            )
        elif self.type is FileTagFilerType.FILE_TAG_FILTER_TYPE_PREFIX:
            return FileTagFilterProto(
                tag_prefix=self.value,
            )
        else:
            return None



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class UserDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    id: builtins.str
    """User id"""
    display_name: builtins.str
    """User display name"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        display_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["display_name", b"display_name", "id", b"id"]) -> None: ...

global___UserDetails = UserDetails

class EnvironmentDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    CONFIGURATION_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Environment id"""
    @property
    def configuration(self) -> global___EnvironmentConfiguration:
        """Environment configuration"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        configuration: global___EnvironmentConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["configuration", b"configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["configuration", b"configuration", "id", b"id"]) -> None: ...

global___EnvironmentDetails = EnvironmentDetails

class EnvironmentConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EDGE_SERVICES_URL_FIELD_NUMBER: builtins.int
    MANAGEMENT_ACCESS_URL_FIELD_NUMBER: builtins.int
    MODEL_API_URL_FIELD_NUMBER: builtins.int
    ANALYTICS_DATA_API_URL_FIELD_NUMBER: builtins.int
    OBJECT_STORAGE_BUCKET_FIELD_NUMBER: builtins.int
    BI_SYSTEM_API_KEY_FIELD_NUMBER: builtins.int
    CLOUD_CONFIGURATION_FIELD_NUMBER: builtins.int
    edge_services_url: builtins.str
    """The Grpc service url on edge"""
    management_access_url: builtins.str
    """The management url of inter qwak services communication"""
    model_api_url: builtins.str
    """The endpoint of the models of actions like inference"""
    analytics_data_api_url: builtins.str
    """The endpoint which the analytics data is send to"""
    object_storage_bucket: builtins.str
    """The object storage bucket name of the environment"""
    bi_system_api_key: builtins.str
    """The BI system token of the environment"""
    @property
    def cloud_configuration(self) -> global___QwakCloudConfiguration:
        """Configuration specific for the environment hosting cloud"""
    def __init__(
        self,
        *,
        edge_services_url: builtins.str = ...,
        management_access_url: builtins.str = ...,
        model_api_url: builtins.str = ...,
        analytics_data_api_url: builtins.str = ...,
        object_storage_bucket: builtins.str = ...,
        bi_system_api_key: builtins.str = ...,
        cloud_configuration: global___QwakCloudConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cloud_configuration", b"cloud_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["analytics_data_api_url", b"analytics_data_api_url", "bi_system_api_key", b"bi_system_api_key", "cloud_configuration", b"cloud_configuration", "edge_services_url", b"edge_services_url", "management_access_url", b"management_access_url", "model_api_url", b"model_api_url", "object_storage_bucket", b"object_storage_bucket"]) -> None: ...

global___EnvironmentConfiguration = EnvironmentConfiguration

class QwakCloudConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AWS_CLOUD_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def aws_cloud_configuration(self) -> global___AwsCloudConfiguration: ...
    def __init__(
        self,
        *,
        aws_cloud_configuration: global___AwsCloudConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["aws_cloud_configuration", b"aws_cloud_configuration", "configuration", b"configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aws_cloud_configuration", b"aws_cloud_configuration", "configuration", b"configuration"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["configuration", b"configuration"]) -> typing_extensions.Literal["aws_cloud_configuration"] | None: ...

global___QwakCloudConfiguration = QwakCloudConfiguration

class AwsCloudConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGION_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    EXTERNAL_ID_FIELD_NUMBER: builtins.int
    WORKGROUP_FIELD_NUMBER: builtins.int
    region: builtins.str
    """The region of the environment"""
    role_arn: builtins.str
    """The role ARN which qwak platform perform actions on behalf"""
    external_id: builtins.str
    """The external id that is needed to assume the role_arn"""
    workgroup: builtins.str
    """The workgroup that is needed to perform actions on Athena"""
    def __init__(
        self,
        *,
        region: builtins.str = ...,
        role_arn: builtins.str = ...,
        external_id: builtins.str = ...,
        workgroup: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["external_id", b"external_id", "region", b"region", "role_arn", b"role_arn", "workgroup", b"workgroup"]) -> None: ...

global___AwsCloudConfiguration = AwsCloudConfiguration



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.feature_store.sources.data_source_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class CreateDataSourceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_SOURCE_SPEC_FIELD_NUMBER: builtins.int
    @property
    def data_source_spec(self) -> qwak.feature_store.sources.data_source_pb2.DataSourceSpec:
        """Data source specifications to create"""
    def __init__(
        self,
        *,
        data_source_spec: qwak.feature_store.sources.data_source_pb2.DataSourceSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["data_source_spec", b"data_source_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_source_spec", b"data_source_spec"]) -> None: ...

global___CreateDataSourceRequest = CreateDataSourceRequest

class CreateDataSourceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_SOURCE_FIELD_NUMBER: builtins.int
    @property
    def data_source(self) -> qwak.feature_store.sources.data_source_pb2.DataSource:
        """The newly created data source"""
    def __init__(
        self,
        *,
        data_source: qwak.feature_store.sources.data_source_pb2.DataSource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["data_source", b"data_source"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_source", b"data_source"]) -> None: ...

global___CreateDataSourceResponse = CreateDataSourceResponse

class UpdateDataSourceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_SOURCE_ID_FIELD_NUMBER: builtins.int
    DATA_SOURCE_SPEC_FIELD_NUMBER: builtins.int
    data_source_id: builtins.str
    """Data source ID to update"""
    @property
    def data_source_spec(self) -> qwak.feature_store.sources.data_source_pb2.DataSourceSpec:
        """Data source specifications to update"""
    def __init__(
        self,
        *,
        data_source_id: builtins.str = ...,
        data_source_spec: qwak.feature_store.sources.data_source_pb2.DataSourceSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["data_source_spec", b"data_source_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_source_id", b"data_source_id", "data_source_spec", b"data_source_spec"]) -> None: ...

global___UpdateDataSourceRequest = UpdateDataSourceRequest

class UpdateDataSourceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_SOURCE_FIELD_NUMBER: builtins.int
    @property
    def data_source(self) -> qwak.feature_store.sources.data_source_pb2.DataSource:
        """The updated data source"""
    def __init__(
        self,
        *,
        data_source: qwak.feature_store.sources.data_source_pb2.DataSource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["data_source", b"data_source"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_source", b"data_source"]) -> None: ...

global___UpdateDataSourceResponse = UpdateDataSourceResponse

class DeleteDataSourceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_SOURCE_ID_FIELD_NUMBER: builtins.int
    data_source_id: builtins.str
    """ID of the data source to delete"""
    def __init__(
        self,
        *,
        data_source_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_source_id", b"data_source_id"]) -> None: ...

global___DeleteDataSourceRequest = DeleteDataSourceRequest

class DeleteDataSourceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteDataSourceResponse = DeleteDataSourceResponse

class GetDataSourceByIdRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_SOURCE_ID_FIELD_NUMBER: builtins.int
    data_source_id: builtins.str
    """ID of the data source to fetch"""
    def __init__(
        self,
        *,
        data_source_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_source_id", b"data_source_id"]) -> None: ...

global___GetDataSourceByIdRequest = GetDataSourceByIdRequest

class GetDataSourceByIdResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_SOURCE_FIELD_NUMBER: builtins.int
    @property
    def data_source(self) -> qwak.feature_store.sources.data_source_pb2.DataSource:
        """Fetched Data Source"""
    def __init__(
        self,
        *,
        data_source: qwak.feature_store.sources.data_source_pb2.DataSource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["data_source", b"data_source"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_source", b"data_source"]) -> None: ...

global___GetDataSourceByIdResponse = GetDataSourceByIdResponse

class GetDataSourceByNameRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_SOURCE_NAME_FIELD_NUMBER: builtins.int
    data_source_name: builtins.str
    """Name of the data source to fetch"""
    def __init__(
        self,
        *,
        data_source_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_source_name", b"data_source_name"]) -> None: ...

global___GetDataSourceByNameRequest = GetDataSourceByNameRequest

class GetDataSourceByNameResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_SOURCE_FIELD_NUMBER: builtins.int
    @property
    def data_source(self) -> qwak.feature_store.sources.data_source_pb2.DataSource:
        """Fetched Data Source"""
    def __init__(
        self,
        *,
        data_source: qwak.feature_store.sources.data_source_pb2.DataSource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["data_source", b"data_source"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_source", b"data_source"]) -> None: ...

global___GetDataSourceByNameResponse = GetDataSourceByNameResponse

class ListDataSourcesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListDataSourcesRequest = ListDataSourcesRequest

class ListDataSourcesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_SOURCES_FIELD_NUMBER: builtins.int
    @property
    def data_sources(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.feature_store.sources.data_source_pb2.DataSource]:
        """All the data sources belonging to the callers' partner id / user id"""
    def __init__(
        self,
        *,
        data_sources: collections.abc.Iterable[qwak.feature_store.sources.data_source_pb2.DataSource] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_sources", b"data_sources"]) -> None: ...

global___ListDataSourcesResponse = ListDataSourcesResponse

class CreateDataSourceUploadURLRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_SOURCE_NAME_FIELD_NUMBER: builtins.int
    OBJECT_NAME_FIELD_NUMBER: builtins.int
    data_source_name: builtins.str
    """Data source name"""
    object_name: builtins.str
    """Object name"""
    def __init__(
        self,
        *,
        data_source_name: builtins.str = ...,
        object_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_source_name", b"data_source_name", "object_name", b"object_name"]) -> None: ...

global___CreateDataSourceUploadURLRequest = CreateDataSourceUploadURLRequest

class CreateDataSourceUploadURLResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UPLOAD_URL_FIELD_NUMBER: builtins.int
    upload_url: builtins.str
    """Upload url intended for the data source configuration"""
    def __init__(
        self,
        *,
        upload_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["upload_url", b"upload_url"]) -> None: ...

global___CreateDataSourceUploadURLResponse = CreateDataSourceUploadURLResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/runtime_configuration/v0/external/elasticsearch_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.administration.runtime_configuration.v0.creds import auth_pb2 as qwak_dot_administration_dot_runtime__configuration_dot_v0_dot_creds_dot_auth__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nPqwak/administration/runtime_configuration/v0/external/elasticsearch_config.proto\x12Jqwak.administration.runtime_configuration.v0.external.elasticsearch_config\x1a=qwak/administration/runtime_configuration/v0/creds/auth.proto\"\x9d\x01\n\x1a\x45lasticsearchConfiguration\x12S\n\x05\x62\x61sic\x18\x01 \x01(\x0b\x32\x42.qwak.administration.runtime_configuration.v0.creds.auth.BasicAuthH\x00\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\x05\x42\x0b\n\tauth_typeB\xfc\x01\nCcom.jfrog.ml.runtime_configuration.v0.external.elasticsearch_configP\x01Z\xb2\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0/external;runtime_configuration_v0_externalb\x06proto3')



_ELASTICSEARCHCONFIGURATION = DESCRIPTOR.message_types_by_name['ElasticsearchConfiguration']
ElasticsearchConfiguration = _reflection.GeneratedProtocolMessageType('ElasticsearchConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _ELASTICSEARCHCONFIGURATION,
  '__module__' : 'qwak.administration.runtime_configuration.v0.external.elasticsearch_config_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.runtime_configuration.v0.external.elasticsearch_config.ElasticsearchConfiguration)
  })
_sym_db.RegisterMessage(ElasticsearchConfiguration)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nCcom.jfrog.ml.runtime_configuration.v0.external.elasticsearch_configP\001Z\262\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0/external;runtime_configuration_v0_external'
  _ELASTICSEARCHCONFIGURATION._serialized_start=224
  _ELASTICSEARCHCONFIGURATION._serialized_end=381
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: jfml/hosting_gateway/v1/build_upload_url.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.jfml/hosting_gateway/v1/build_upload_url.proto\x12\x17jfml.hosting_gateway.v1\"\xd3\x01\n\x18\x42uildUploadUrlParameters\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x10\n\x08\x62uild_id\x18\x02 \x01(\t\x12\x11\n\ttag_value\x18\x03 \x01(\t\x12\x41\n\rartifact_type\x18\x04 \x01(\x0e\x32*.jfml.hosting_gateway.v1.BuildArtifactType\x12$\n\x1ause_cloud_provider_storage\x18\x05 \x01(\x08H\x00\x42\x17\n\x15\x63loud_provider_option*v\n\x11\x42uildArtifactType\x12\x19\n\x15INVALID_ARTIFACT_TYPE\x10\x00\x12\x16\n\x12\x44\x41TA_ARTIFACT_TYPE\x10\x01\x12\x16\n\x12\x46ILE_ARTIFACT_TYPE\x10\x02\x12\x16\n\x12\x43ODE_ARTIFACT_TYPE\x10\x03\x42\'\n#com.jfrog.ml.hosting_gateway.api.v1P\x01\x62\x06proto3')

_BUILDARTIFACTTYPE = DESCRIPTOR.enum_types_by_name['BuildArtifactType']
BuildArtifactType = enum_type_wrapper.EnumTypeWrapper(_BUILDARTIFACTTYPE)
INVALID_ARTIFACT_TYPE = 0
DATA_ARTIFACT_TYPE = 1
FILE_ARTIFACT_TYPE = 2
CODE_ARTIFACT_TYPE = 3


_BUILDUPLOADURLPARAMETERS = DESCRIPTOR.message_types_by_name['BuildUploadUrlParameters']
BuildUploadUrlParameters = _reflection.GeneratedProtocolMessageType('BuildUploadUrlParameters', (_message.Message,), {
  'DESCRIPTOR' : _BUILDUPLOADURLPARAMETERS,
  '__module__' : 'jfml.hosting_gateway.v1.build_upload_url_pb2'
  # @@protoc_insertion_point(class_scope:jfml.hosting_gateway.v1.BuildUploadUrlParameters)
  })
_sym_db.RegisterMessage(BuildUploadUrlParameters)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#com.jfrog.ml.hosting_gateway.api.v1P\001'
  _BUILDARTIFACTTYPE._serialized_start=289
  _BUILDARTIFACTTYPE._serialized_end=407
  _BUILDUPLOADURLPARAMETERS._serialized_start=76
  _BUILDUPLOADURLPARAMETERS._serialized_end=287
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/integration/slack_app_integration.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,qwak/integration/slack_app_integration.proto\x12\x1bqwak.integration.management\"\x9f\x02\n\x13SlackAppIntegration\x12\\\n\x1f\x65ncrypted_slack_app_auth_config\x18\x01 \x01(\x0b\x32/.qwak.integration.management.SlackAppAuthConfigB\x02\x18\x01\x12I\n\x12slack_app_settings\x18\x02 \x01(\x0b\x32-.qwak.integration.management.SlackAppSettings\x12W\n\x13slack_system_secret\x18\x03 \x01(\x0b\x32\x38.qwak.integration.management.SlackSystemSecretDescriptorH\x00\x42\x06\n\x04\x61uth\"\x8e\x01\n\x17SlackAppIntegrationSpec\x12\x64\n\x1fslack_app_temporary_credentials\x18\x01 \x01(\x0b\x32\x39.qwak.integration.management.SlackAppTemporaryCredentialsH\x00\x42\r\n\x0b\x63redentials\"Q\n\x1cSlackAppTemporaryCredentials\x12\r\n\x05state\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x14\n\x0credirect_uri\x18\x03 \x01(\t\"\xa6\x01\n\x10SlackAppSettings\x12:\n\nslack_team\x18\x01 \x01(\x0b\x32&.qwak.integration.management.SlackTeam\x12H\n\x10slack_enterprise\x18\x02 \x01(\x0b\x32,.qwak.integration.management.SlackEnterpriseH\x00\x42\x0c\n\nenterprise\",\n\x12SlackAppAuthConfig\x12\x16\n\x0e\x62ot_user_token\x18\x01 \x01(\t\"V\n\x1bSlackSystemSecretDescriptor\x12\x13\n\x0bsecret_name\x18\x01 \x01(\t\x12\x0f\n\x07url_key\x18\x02 \x01(\t\x12\x11\n\ttoken_key\x18\x03 \x01(\t\"\x18\n\x16SlackAppValidationSpec\"\x1c\n\x1aSlackAppIntegrationOptions\"%\n\tSlackTeam\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"+\n\x0fSlackEnterprise\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\tBH\n&com.qwak.ai.management.integration.apiP\x01Z\x1cqwak/integration;integrationb\x06proto3')



_SLACKAPPINTEGRATION = DESCRIPTOR.message_types_by_name['SlackAppIntegration']
_SLACKAPPINTEGRATIONSPEC = DESCRIPTOR.message_types_by_name['SlackAppIntegrationSpec']
_SLACKAPPTEMPORARYCREDENTIALS = DESCRIPTOR.message_types_by_name['SlackAppTemporaryCredentials']
_SLACKAPPSETTINGS = DESCRIPTOR.message_types_by_name['SlackAppSettings']
_SLACKAPPAUTHCONFIG = DESCRIPTOR.message_types_by_name['SlackAppAuthConfig']
_SLACKSYSTEMSECRETDESCRIPTOR = DESCRIPTOR.message_types_by_name['SlackSystemSecretDescriptor']
_SLACKAPPVALIDATIONSPEC = DESCRIPTOR.message_types_by_name['SlackAppValidationSpec']
_SLACKAPPINTEGRATIONOPTIONS = DESCRIPTOR.message_types_by_name['SlackAppIntegrationOptions']
_SLACKTEAM = DESCRIPTOR.message_types_by_name['SlackTeam']
_SLACKENTERPRISE = DESCRIPTOR.message_types_by_name['SlackEnterprise']
SlackAppIntegration = _reflection.GeneratedProtocolMessageType('SlackAppIntegration', (_message.Message,), {
  'DESCRIPTOR' : _SLACKAPPINTEGRATION,
  '__module__' : 'qwak.integration.slack_app_integration_pb2'
  # @@protoc_insertion_point(class_scope:qwak.integration.management.SlackAppIntegration)
  })
_sym_db.RegisterMessage(SlackAppIntegration)

SlackAppIntegrationSpec = _reflection.GeneratedProtocolMessageType('SlackAppIntegrationSpec', (_message.Message,), {
  'DESCRIPTOR' : _SLACKAPPINTEGRATIONSPEC,
  '__module__' : 'qwak.integration.slack_app_integration_pb2'
  # @@protoc_insertion_point(class_scope:qwak.integration.management.SlackAppIntegrationSpec)
  })
_sym_db.RegisterMessage(SlackAppIntegrationSpec)

SlackAppTemporaryCredentials = _reflection.GeneratedProtocolMessageType('SlackAppTemporaryCredentials', (_message.Message,), {
  'DESCRIPTOR' : _SLACKAPPTEMPORARYCREDENTIALS,
  '__module__' : 'qwak.integration.slack_app_integration_pb2'
  # @@protoc_insertion_point(class_scope:qwak.integration.management.SlackAppTemporaryCredentials)
  })
_sym_db.RegisterMessage(SlackAppTemporaryCredentials)

SlackAppSettings = _reflection.GeneratedProtocolMessageType('SlackAppSettings', (_message.Message,), {
  'DESCRIPTOR' : _SLACKAPPSETTINGS,
  '__module__' : 'qwak.integration.slack_app_integration_pb2'
  # @@protoc_insertion_point(class_scope:qwak.integration.management.SlackAppSettings)
  })
_sym_db.RegisterMessage(SlackAppSettings)

SlackAppAuthConfig = _reflection.GeneratedProtocolMessageType('SlackAppAuthConfig', (_message.Message,), {
  'DESCRIPTOR' : _SLACKAPPAUTHCONFIG,
  '__module__' : 'qwak.integration.slack_app_integration_pb2'
  # @@protoc_insertion_point(class_scope:qwak.integration.management.SlackAppAuthConfig)
  })
_sym_db.RegisterMessage(SlackAppAuthConfig)

SlackSystemSecretDescriptor = _reflection.GeneratedProtocolMessageType('SlackSystemSecretDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _SLACKSYSTEMSECRETDESCRIPTOR,
  '__module__' : 'qwak.integration.slack_app_integration_pb2'
  # @@protoc_insertion_point(class_scope:qwak.integration.management.SlackSystemSecretDescriptor)
  })
_sym_db.RegisterMessage(SlackSystemSecretDescriptor)

SlackAppValidationSpec = _reflection.GeneratedProtocolMessageType('SlackAppValidationSpec', (_message.Message,), {
  'DESCRIPTOR' : _SLACKAPPVALIDATIONSPEC,
  '__module__' : 'qwak.integration.slack_app_integration_pb2'
  # @@protoc_insertion_point(class_scope:qwak.integration.management.SlackAppValidationSpec)
  })
_sym_db.RegisterMessage(SlackAppValidationSpec)

SlackAppIntegrationOptions = _reflection.GeneratedProtocolMessageType('SlackAppIntegrationOptions', (_message.Message,), {
  'DESCRIPTOR' : _SLACKAPPINTEGRATIONOPTIONS,
  '__module__' : 'qwak.integration.slack_app_integration_pb2'
  # @@protoc_insertion_point(class_scope:qwak.integration.management.SlackAppIntegrationOptions)
  })
_sym_db.RegisterMessage(SlackAppIntegrationOptions)

SlackTeam = _reflection.GeneratedProtocolMessageType('SlackTeam', (_message.Message,), {
  'DESCRIPTOR' : _SLACKTEAM,
  '__module__' : 'qwak.integration.slack_app_integration_pb2'
  # @@protoc_insertion_point(class_scope:qwak.integration.management.SlackTeam)
  })
_sym_db.RegisterMessage(SlackTeam)

SlackEnterprise = _reflection.GeneratedProtocolMessageType('SlackEnterprise', (_message.Message,), {
  'DESCRIPTOR' : _SLACKENTERPRISE,
  '__module__' : 'qwak.integration.slack_app_integration_pb2'
  # @@protoc_insertion_point(class_scope:qwak.integration.management.SlackEnterprise)
  })
_sym_db.RegisterMessage(SlackEnterprise)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&com.qwak.ai.management.integration.apiP\001Z\034qwak/integration;integration'
  _SLACKAPPINTEGRATION.fields_by_name['encrypted_slack_app_auth_config']._options = None
  _SLACKAPPINTEGRATION.fields_by_name['encrypted_slack_app_auth_config']._serialized_options = b'\030\001'
  _SLACKAPPINTEGRATION._serialized_start=78
  _SLACKAPPINTEGRATION._serialized_end=365
  _SLACKAPPINTEGRATIONSPEC._serialized_start=368
  _SLACKAPPINTEGRATIONSPEC._serialized_end=510
  _SLACKAPPTEMPORARYCREDENTIALS._serialized_start=512
  _SLACKAPPTEMPORARYCREDENTIALS._serialized_end=593
  _SLACKAPPSETTINGS._serialized_start=596
  _SLACKAPPSETTINGS._serialized_end=762
  _SLACKAPPAUTHCONFIG._serialized_start=764
  _SLACKAPPAUTHCONFIG._serialized_end=808
  _SLACKSYSTEMSECRETDESCRIPTOR._serialized_start=810
  _SLACKSYSTEMSECRETDESCRIPTOR._serialized_end=896
  _SLACKAPPVALIDATIONSPEC._serialized_start=898
  _SLACKAPPVALIDATIONSPEC._serialized_end=922
  _SLACKAPPINTEGRATIONOPTIONS._serialized_start=924
  _SLACKAPPINTEGRATIONOPTIONS._serialized_end=952
  _SLACKTEAM._serialized_start=954
  _SLACKTEAM._serialized_end=991
  _SLACKENTERPRISE._serialized_start=993
  _SLACKENTERPRISE._serialized_end=1036
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/runtime_configuration/v0/runtime_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.administration.runtime_configuration.v0 import feature_store_config_pb2 as qwak_dot_administration_dot_runtime__configuration_dot_v0_dot_feature__store__config__pb2
from _qwak_proto.qwak.administration.runtime_configuration.v0 import sql_engine_config_pb2 as qwak_dot_administration_dot_runtime__configuration_dot_v0_dot_sql__engine__config__pb2
from _qwak_proto.qwak.administration.runtime_configuration.v0 import data_catalog_config_pb2 as qwak_dot_administration_dot_runtime__configuration_dot_v0_dot_data__catalog__config__pb2
from _qwak_proto.qwak.administration.runtime_configuration.v0 import logs_storage_config_pb2 as qwak_dot_administration_dot_runtime__configuration_dot_v0_dot_logs__storage__config__pb2
from _qwak_proto.qwak.administration.runtime_configuration.v0 import object_storage_config_pb2 as qwak_dot_administration_dot_runtime__configuration_dot_v0_dot_object__storage__config__pb2
from _qwak_proto.qwak.administration.runtime_configuration.v0 import hosting_config_pb2 as qwak_dot_administration_dot_runtime__configuration_dot_v0_dot_hosting__config__pb2
from _qwak_proto.qwak.administration.runtime_configuration.v0 import model_analytics_storage_config_pb2 as qwak_dot_administration_dot_runtime__configuration_dot_v0_dot_model__analytics__storage__config__pb2
from _qwak_proto.qwak.administration.runtime_configuration.v0 import observability_config_pb2 as qwak_dot_administration_dot_runtime__configuration_dot_v0_dot_observability__config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAqwak/administration/runtime_configuration/v0/runtime_config.proto\x12,qwak.administration.runtime_configuration.v0\x1aGqwak/administration/runtime_configuration/v0/feature_store_config.proto\x1a\x44qwak/administration/runtime_configuration/v0/sql_engine_config.proto\x1a\x46qwak/administration/runtime_configuration/v0/data_catalog_config.proto\x1a\x46qwak/administration/runtime_configuration/v0/logs_storage_config.proto\x1aHqwak/administration/runtime_configuration/v0/object_storage_config.proto\x1a\x41qwak/administration/runtime_configuration/v0/hosting_config.proto\x1aQqwak/administration/runtime_configuration/v0/model_analytics_storage_config.proto\x1aGqwak/administration/runtime_configuration/v0/observability_config.proto\"\xb3\x08\n\x14RuntimeConfiguration\x12p\n\x15hosting_configuration\x18\x01 \x01(\x0b\x32Q.qwak.administration.runtime_configuration.v0.hosting_config.HostingConfiguration\x12\x81\x01\n\x1b\x66\x65\x61ture_store_configuration\x18\x02 \x01(\x0b\x32\\.qwak.administration.runtime_configuration.v0.feature_store_config.FeatureStoreConfiguration\x12\x84\x01\n\x1cobject_storage_configuration\x18\x03 \x01(\x0b\x32^.qwak.administration.runtime_configuration.v0.object_storage_config.ObjectStorageConfiguration\x12~\n\x1alogs_storage_configuration\x18\x04 \x01(\x0b\x32Z.qwak.administration.runtime_configuration.v0.logs_storage_config.LogsStorageConfiguration\x12~\n\x1a\x64\x61ta_catalog_configuration\x18\x05 \x01(\x0b\x32Z.qwak.administration.runtime_configuration.v0.data_catalog_config.DataCatalogConfiguration\x12x\n\x18sql_engine_configuration\x18\x06 \x01(\x0b\x32V.qwak.administration.runtime_configuration.v0.sql_engine_config.SqlEngineConfiguration\x12\x9e\x01\n%model_analytics_storage_configuration\x18\x07 \x01(\x0b\x32o.qwak.administration.runtime_configuration.v0.model_analytics_storage_config.ModelAnalyticsStorageConfiguration\x12\x82\x01\n\x1bobservability_configuration\x18\x08 \x01(\x0b\x32].qwak.administration.runtime_configuration.v0.observability_config.ObservabilityConfigurationB\xcc\x01\n%com.jfrog.ml.runtime_configuration.v0P\x01Z\xa0\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0;runtime_configuration_v0b\x06proto3')



_RUNTIMECONFIGURATION = DESCRIPTOR.message_types_by_name['RuntimeConfiguration']
RuntimeConfiguration = _reflection.GeneratedProtocolMessageType('RuntimeConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _RUNTIMECONFIGURATION,
  '__module__' : 'qwak.administration.runtime_configuration.v0.runtime_config_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.runtime_configuration.v0.RuntimeConfiguration)
  })
_sym_db.RegisterMessage(RuntimeConfiguration)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.jfrog.ml.runtime_configuration.v0P\001Z\240\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0;runtime_configuration_v0'
  _RUNTIMECONFIGURATION._serialized_start=700
  _RUNTIMECONFIGURATION._serialized_end=1775
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/runtime_configuration/v0/external/victoriametrics_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nRqwak/administration/runtime_configuration/v0/external/victoriametrics_config.proto\x12Lqwak.administration.runtime_configuration.v0.external.victoriametrics_config\"\x1e\n\x1cVictoriaMetricsConfigurationB\xfe\x01\nEcom.jfrog.ml.runtime_configuration.v0.external.victoriametrics_configP\x01Z\xb2\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0/external;runtime_configuration_v0_externalb\x06proto3')



_VICTORIAMETRICSCONFIGURATION = DESCRIPTOR.message_types_by_name['VictoriaMetricsConfiguration']
VictoriaMetricsConfiguration = _reflection.GeneratedProtocolMessageType('VictoriaMetricsConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _VICTORIAMETRICSCONFIGURATION,
  '__module__' : 'qwak.administration.runtime_configuration.v0.external.victoriametrics_config_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.runtime_configuration.v0.external.victoriametrics_config.VictoriaMetricsConfiguration)
  })
_sym_db.RegisterMessage(VictoriaMetricsConfiguration)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nEcom.jfrog.ml.runtime_configuration.v0.external.victoriametrics_configP\001Z\262\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0/external;runtime_configuration_v0_external'
  _VICTORIAMETRICSCONFIGURATION._serialized_start=164
  _VICTORIAMETRICSCONFIGURATION._serialized_end=194
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class VariationMapping(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SELECTED_VARIATION_MAPPING_NAME_FIELD_NUMBER: builtins.int
    TRAFFIC_REQUEST_TIMEOUT_MS_FIELD_NUMBER: builtins.int
    DEPLOYMENT_ID_FIELD_NUMBER: builtins.int
    TRAFFIC_MAPPING_SPEC_FIELD_NUMBER: builtins.int
    selected_variation_mapping_name: builtins.str
    """Variation name"""
    traffic_request_timeout_ms: builtins.int
    """Timeout of the request in ms"""
    deployment_id: builtins.str
    """Deployment id which the variation mapping apply to"""
    @property
    def traffic_mapping_spec(self) -> global___TrafficMappingSpec: ...
    def __init__(
        self,
        *,
        selected_variation_mapping_name: builtins.str = ...,
        traffic_request_timeout_ms: builtins.int = ...,
        deployment_id: builtins.str = ...,
        traffic_mapping_spec: global___TrafficMappingSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["mapping_spec", b"mapping_spec", "traffic_mapping_spec", b"traffic_mapping_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["deployment_id", b"deployment_id", "mapping_spec", b"mapping_spec", "selected_variation_mapping_name", b"selected_variation_mapping_name", "traffic_mapping_spec", b"traffic_mapping_spec", "traffic_request_timeout_ms", b"traffic_request_timeout_ms"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["mapping_spec", b"mapping_spec"]) -> typing_extensions.Literal["traffic_mapping_spec"] | None: ...

global___VariationMapping = VariationMapping

class TrafficMappingSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PERCENTAGE_FIELD_NUMBER: builtins.int
    IS_SHADOW_FIELD_NUMBER: builtins.int
    percentage: builtins.int
    """Percentage to deflect traffic to."""
    is_shadow: builtins.bool
    """Is shadow"""
    def __init__(
        self,
        *,
        percentage: builtins.int = ...,
        is_shadow: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_shadow", b"is_shadow", "percentage", b"percentage"]) -> None: ...

global___TrafficMappingSpec = TrafficMappingSpec



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/vectors/v1/vector.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cqwak/vectors/v1/vector.proto\x12\x1cqwak.vector.store.serving.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\x1f\n\x0c\x44oubleVector\x12\x0f\n\x07\x65lement\x18\x01 \x03(\x01\"\xc0\x01\n\x08Property\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\nstring_val\x18\x02 \x01(\tH\x00\x12\x11\n\x07int_val\x18\x03 \x01(\x03H\x00\x12\x12\n\x08\x62ool_val\x18\x04 \x01(\x08H\x00\x12\x14\n\ndouble_val\x18\x05 \x01(\x01H\x00\x12\x33\n\rtimestamp_val\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x12\x10\n\x08is_empty\x18\x07 \x01(\x08\x42\x0c\n\nvalue_type\"\xa4\x01\n\x0cSearchResult\x12\n\n\x02id\x18\x01 \x01(\t\x12:\n\x06vector\x18\x02 \x01(\x0b\x32*.qwak.vector.store.serving.v1.DoubleVector\x12:\n\nproperties\x18\x03 \x03(\x0b\x32&.qwak.vector.store.serving.v1.Property\x12\x10\n\x08\x64istance\x18\x04 \x01(\x01\"\xe1\x01\n\x0cStoredVector\x12\x0e\n\x02id\x18\x01 \x01(\tB\x02\x18\x01\x12:\n\x06vector\x18\x02 \x01(\x0b\x32*.qwak.vector.store.serving.v1.DoubleVector\x12:\n\nproperties\x18\x03 \x03(\x0b\x32&.qwak.vector.store.serving.v1.Property\x12I\n\x11vector_identifier\x18\x04 \x01(\x0b\x32..qwak.vector.store.serving.v1.VectorIdentifier\"M\n\x10VectorIdentifier\x12\x11\n\tvector_id\x18\x01 \x01(\t\x12\x13\n\ttenant_id\x18\x02 \x01(\tH\x00\x42\x11\n\x0foptional_tenantB\x1e\n\x1a\x63om.qwak.ai.vectors.api.v1P\x01\x62\x06proto3')



_DOUBLEVECTOR = DESCRIPTOR.message_types_by_name['DoubleVector']
_PROPERTY = DESCRIPTOR.message_types_by_name['Property']
_SEARCHRESULT = DESCRIPTOR.message_types_by_name['SearchResult']
_STOREDVECTOR = DESCRIPTOR.message_types_by_name['StoredVector']
_VECTORIDENTIFIER = DESCRIPTOR.message_types_by_name['VectorIdentifier']
DoubleVector = _reflection.GeneratedProtocolMessageType('DoubleVector', (_message.Message,), {
  'DESCRIPTOR' : _DOUBLEVECTOR,
  '__module__' : 'qwak.vectors.v1.vector_pb2'
  # @@protoc_insertion_point(class_scope:qwak.vector.store.serving.v1.DoubleVector)
  })
_sym_db.RegisterMessage(DoubleVector)

Property = _reflection.GeneratedProtocolMessageType('Property', (_message.Message,), {
  'DESCRIPTOR' : _PROPERTY,
  '__module__' : 'qwak.vectors.v1.vector_pb2'
  # @@protoc_insertion_point(class_scope:qwak.vector.store.serving.v1.Property)
  })
_sym_db.RegisterMessage(Property)

SearchResult = _reflection.GeneratedProtocolMessageType('SearchResult', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHRESULT,
  '__module__' : 'qwak.vectors.v1.vector_pb2'
  # @@protoc_insertion_point(class_scope:qwak.vector.store.serving.v1.SearchResult)
  })
_sym_db.RegisterMessage(SearchResult)

StoredVector = _reflection.GeneratedProtocolMessageType('StoredVector', (_message.Message,), {
  'DESCRIPTOR' : _STOREDVECTOR,
  '__module__' : 'qwak.vectors.v1.vector_pb2'
  # @@protoc_insertion_point(class_scope:qwak.vector.store.serving.v1.StoredVector)
  })
_sym_db.RegisterMessage(StoredVector)

VectorIdentifier = _reflection.GeneratedProtocolMessageType('VectorIdentifier', (_message.Message,), {
  'DESCRIPTOR' : _VECTORIDENTIFIER,
  '__module__' : 'qwak.vectors.v1.vector_pb2'
  # @@protoc_insertion_point(class_scope:qwak.vector.store.serving.v1.VectorIdentifier)
  })
_sym_db.RegisterMessage(VectorIdentifier)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032com.qwak.ai.vectors.api.v1P\001'
  _STOREDVECTOR.fields_by_name['id']._options = None
  _STOREDVECTOR.fields_by_name['id']._serialized_options = b'\030\001'
  _DOUBLEVECTOR._serialized_start=95
  _DOUBLEVECTOR._serialized_end=126
  _PROPERTY._serialized_start=129
  _PROPERTY._serialized_end=321
  _SEARCHRESULT._serialized_start=324
  _SEARCHRESULT._serialized_end=488
  _STOREDVECTOR._serialized_start=491
  _STOREDVECTOR._serialized_end=716
  _VECTORIDENTIFIER._serialized_start=718
  _VECTORIDENTIFIER._serialized_end=795
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import qwak.execution.v1.backfill_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _JobStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _JobStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_JobStatus.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    JOB_STATUS_INVALID: _JobStatus.ValueType  # 0
    """Job state"""
    JOB_STATUS_COMPLETED: _JobStatus.ValueType  # 3
    """Job has completed"""
    JOB_STATUS_FAILED: _JobStatus.ValueType  # 4
    """Job has failed"""
    JOB_STATUS_TOO_EARLY: _JobStatus.ValueType  # 5
    """Job is too early - we shouldn't get there but that's a marker"""
    LEGACY_JOB_STATUS_RUNNING: _JobStatus.ValueType  # 6
    """This is for supporting initPagination and showing jobs from the legacy job service - job is running"""
    LEGACY_JOB_STATUS_PENDING: _JobStatus.ValueType  # 7
    """This is for supporting initPagination and showing jobs from the legacy job service - job is pending"""

class JobStatus(_JobStatus, metaclass=_JobStatusEnumTypeWrapper): ...

JOB_STATUS_INVALID: JobStatus.ValueType  # 0
"""Job state"""
JOB_STATUS_COMPLETED: JobStatus.ValueType  # 3
"""Job has completed"""
JOB_STATUS_FAILED: JobStatus.ValueType  # 4
"""Job has failed"""
JOB_STATUS_TOO_EARLY: JobStatus.ValueType  # 5
"""Job is too early - we shouldn't get there but that's a marker"""
LEGACY_JOB_STATUS_RUNNING: JobStatus.ValueType  # 6
"""This is for supporting initPagination and showing jobs from the legacy job service - job is running"""
LEGACY_JOB_STATUS_PENDING: JobStatus.ValueType  # 7
"""This is for supporting initPagination and showing jobs from the legacy job service - job is pending"""
global___JobStatus = JobStatus

class JobRecord(google.protobuf.message.Message):
    """Feature Store Job Record.
    Represents a job generated from featureset
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class JobLabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    JOB_ID_FIELD_NUMBER: builtins.int
    LEGACY_RUN_ID_FIELD_NUMBER: builtins.int
    EXECUTION_ID_FIELD_NUMBER: builtins.int
    FEATURESET_NAME_FIELD_NUMBER: builtins.int
    FEATURESET_ID_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    ACCOUNT_ID_FIELD_NUMBER: builtins.int
    JOB_STATUS_FIELD_NUMBER: builtins.int
    CREATION_TIME_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    JOB_METADATA_FIELD_NUMBER: builtins.int
    JOB_LABELS_FIELD_NUMBER: builtins.int
    CODE_FIELD_NUMBER: builtins.int
    INFO_FIELD_NUMBER: builtins.int
    job_id: builtins.str
    """Unique id of the job"""
    legacy_run_id: builtins.int
    """The legacy run id (meaning this job was actually managed by the old job service)"""
    execution_id: builtins.str
    """Execution Manager Execution ID"""
    featureset_name: builtins.str
    """Featureset name"""
    featureset_id: builtins.str
    """Featureset id"""
    environment_id: builtins.str
    """Environment_id"""
    account_id: builtins.str
    """Account ID"""
    job_status: global___JobStatus.ValueType
    """State of the job - whether it's running, failed, pending, etc"""
    @property
    def creation_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Job Creation time - the time at which it arrived at the database"""
    @property
    def start_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Start time - the time at which the job started executing"""
    @property
    def end_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """End time - the time at which the job attained its final status"""
    @property
    def job_metadata(self) -> global___JobMetadata:
        """Job-Specific metadata"""
    @property
    def job_labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Labels/ Tags associated with this job.
        Stuff like Tshirt size/ comments etc. go here
        """
    code: builtins.str
    """Classify this job with a specific code, whether failed or successful"""
    @property
    def info(self) -> global___FailureInformation: ...
    def __init__(
        self,
        *,
        job_id: builtins.str = ...,
        legacy_run_id: builtins.int = ...,
        execution_id: builtins.str = ...,
        featureset_name: builtins.str = ...,
        featureset_id: builtins.str = ...,
        environment_id: builtins.str = ...,
        account_id: builtins.str = ...,
        job_status: global___JobStatus.ValueType = ...,
        creation_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        end_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        job_metadata: global___JobMetadata | None = ...,
        job_labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        code: builtins.str = ...,
        info: global___FailureInformation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["creation_time", b"creation_time", "end_time", b"end_time", "exec_id", b"exec_id", "execution_id", b"execution_id", "failure_info", b"failure_info", "info", b"info", "job_metadata", b"job_metadata", "legacy_run_id", b"legacy_run_id", "start_time", b"start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_id", b"account_id", "code", b"code", "creation_time", b"creation_time", "end_time", b"end_time", "environment_id", b"environment_id", "exec_id", b"exec_id", "execution_id", b"execution_id", "failure_info", b"failure_info", "featureset_id", b"featureset_id", "featureset_name", b"featureset_name", "info", b"info", "job_id", b"job_id", "job_labels", b"job_labels", "job_metadata", b"job_metadata", "job_status", b"job_status", "legacy_run_id", b"legacy_run_id", "start_time", b"start_time"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["exec_id", b"exec_id"]) -> typing_extensions.Literal["legacy_run_id", "execution_id"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["failure_info", b"failure_info"]) -> typing_extensions.Literal["info"] | None: ...

global___JobRecord = JobRecord

class JobMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BATCH_INGESTION_METADATA_FIELD_NUMBER: builtins.int
    BATCH_BACKFILL_INGESTION_METADATA_FIELD_NUMBER: builtins.int
    @property
    def batch_ingestion_metadata(self) -> global___BatchIngestionMetadata:
        """"regular" batch job"""
    @property
    def batch_backfill_ingestion_metadata(self) -> global___BatchBackfillMetadata:
        """batch backfill"""
    def __init__(
        self,
        *,
        batch_ingestion_metadata: global___BatchIngestionMetadata | None = ...,
        batch_backfill_ingestion_metadata: global___BatchBackfillMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["batch_backfill_ingestion_metadata", b"batch_backfill_ingestion_metadata", "batch_ingestion_metadata", b"batch_ingestion_metadata", "metadata_type", b"metadata_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["batch_backfill_ingestion_metadata", b"batch_backfill_ingestion_metadata", "batch_ingestion_metadata", b"batch_ingestion_metadata", "metadata_type", b"metadata_type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["metadata_type", b"metadata_type"]) -> typing_extensions.Literal["batch_ingestion_metadata", "batch_backfill_ingestion_metadata"] | None: ...

global___JobMetadata = JobMetadata

class BatchIngestionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INGESTED_DATA_START_TIME_FIELD_NUMBER: builtins.int
    INGESTED_DATA_END_TIME_FIELD_NUMBER: builtins.int
    NUM_AFFECTED_ROWS_FIELD_NUMBER: builtins.int
    BATCH_EXECUTION_DATE_FIELD_NUMBER: builtins.int
    @property
    def ingested_data_start_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Ingested data window start time"""
    @property
    def ingested_data_end_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Ingested data window end time"""
    num_affected_rows: builtins.int
    """Number of affected rows"""
    @property
    def batch_execution_date(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Logical batch date"""
    def __init__(
        self,
        *,
        ingested_data_start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        ingested_data_end_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        num_affected_rows: builtins.int = ...,
        batch_execution_date: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["batch_execution_date", b"batch_execution_date", "ingested_data_end_time", b"ingested_data_end_time", "ingested_data_start_time", b"ingested_data_start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["batch_execution_date", b"batch_execution_date", "ingested_data_end_time", b"ingested_data_end_time", "ingested_data_start_time", b"ingested_data_start_time", "num_affected_rows", b"num_affected_rows"]) -> None: ...

global___BatchIngestionMetadata = BatchIngestionMetadata

class BatchBackfillMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NUM_INTERVAL_ROWS_FIELD_NUMBER: builtins.int
    BACKFILL_SPEC_FIELD_NUMBER: builtins.int
    NUM_AFFECTED_ROWS_FIELD_NUMBER: builtins.int
    OFFLINE_PROCESSING_START_TIME_FIELD_NUMBER: builtins.int
    OFFLINE_PROCESSING_END_TIME_FIELD_NUMBER: builtins.int
    ONLINE_PROCESSING_START_TIME_FIELD_NUMBER: builtins.int
    ONLINE_PROCESSING_END_TIME_FIELD_NUMBER: builtins.int
    LAST_BATCH_LOGICAL_DATE_FIELD_NUMBER: builtins.int
    num_interval_rows: builtins.int
    """Number of rows in the interval (incoming)"""
    @property
    def backfill_spec(self) -> qwak.execution.v1.backfill_pb2.BackfillSpec:
        """Backfill spec"""
    num_affected_rows: builtins.int
    """Number of affected rows"""
    @property
    def offline_processing_start_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """SYSTEM time where offline processing started"""
    @property
    def offline_processing_end_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """SYSTEM time where offline processing ended"""
    @property
    def online_processing_start_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """SYSTEM time when online processing started"""
    @property
    def online_processing_end_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """SYSTEM time when online processing ended"""
    @property
    def last_batch_logical_date(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Logical time (cron tick) of the last batch in the backfill"""
    def __init__(
        self,
        *,
        num_interval_rows: builtins.int = ...,
        backfill_spec: qwak.execution.v1.backfill_pb2.BackfillSpec | None = ...,
        num_affected_rows: builtins.int = ...,
        offline_processing_start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        offline_processing_end_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        online_processing_start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        online_processing_end_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_batch_logical_date: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["backfill_spec", b"backfill_spec", "last_batch_logical_date", b"last_batch_logical_date", "offline_processing_end_time", b"offline_processing_end_time", "offline_processing_start_time", b"offline_processing_start_time", "online_processing_end_time", b"online_processing_end_time", "online_processing_start_time", b"online_processing_start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["backfill_spec", b"backfill_spec", "last_batch_logical_date", b"last_batch_logical_date", "num_affected_rows", b"num_affected_rows", "num_interval_rows", b"num_interval_rows", "offline_processing_end_time", b"offline_processing_end_time", "offline_processing_start_time", b"offline_processing_start_time", "online_processing_end_time", b"online_processing_end_time", "online_processing_start_time", b"online_processing_start_time"]) -> None: ...

global___BatchBackfillMetadata = BatchBackfillMetadata

class FailureInformation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORIGINAL_ERROR_MESSAGE_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    original_error_message: builtins.str
    """original error message that failed to job"""
    message: builtins.str
    def __init__(
        self,
        *,
        original_error_message: builtins.str = ...,
        message: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["formatted_error_message", b"formatted_error_message", "message", b"message"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["formatted_error_message", b"formatted_error_message", "message", b"message", "original_error_message", b"original_error_message"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["formatted_error_message", b"formatted_error_message"]) -> typing_extensions.Literal["message"] | None: ...

global___FailureInformation = FailureInformation



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.build.v1 import build_api_pb2 as qwak_dot_build_dot_v1_dot_build__api__pb2


class BuildAPIStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.RegisterBuild = channel.unary_unary(
                '/com.qwak.build.v1.BuildAPI/RegisterBuild',
                request_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.RegisterBuildRequest.SerializeToString,
                response_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.RegisterBuildResponse.FromString,
                )
        self.UpdateBuildStatus = channel.unary_unary(
                '/com.qwak.build.v1.BuildAPI/UpdateBuildStatus',
                request_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.UpdateBuildStatusRequest.SerializeToString,
                response_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.UpdateBuildStatusResponse.FromString,
                )
        self.RegisterExperimentTracking = channel.unary_unary(
                '/com.qwak.build.v1.BuildAPI/RegisterExperimentTracking',
                request_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.RegisterExperimentTrackingRequest.SerializeToString,
                response_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.RegisterExperimentTrackingResponse.FromString,
                )
        self.RegisterTags = channel.unary_unary(
                '/com.qwak.build.v1.BuildAPI/RegisterTags',
                request_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.RegisterTagsRequest.SerializeToString,
                response_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.RegisterTagsResponse.FromString,
                )
        self.RegisterModelSchema = channel.unary_unary(
                '/com.qwak.build.v1.BuildAPI/RegisterModelSchema',
                request_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.RegisterModelSchemaRequest.SerializeToString,
                response_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.RegisterModelSchemaResponse.FromString,
                )
        self.GetBuild = channel.unary_unary(
                '/com.qwak.build.v1.BuildAPI/GetBuild',
                request_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.GetBuildRequest.SerializeToString,
                response_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.GetBuildResponse.FromString,
                )
        self.ListBuilds = channel.unary_unary(
                '/com.qwak.build.v1.BuildAPI/ListBuilds',
                request_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.ListBuildsRequest.SerializeToString,
                response_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.ListBuildsResponse.FromString,
                )
        self.DeleteBuild = channel.unary_unary(
                '/com.qwak.build.v1.BuildAPI/DeleteBuild',
                request_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.DeleteBuildRequest.SerializeToString,
                response_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.DeleteBuildResponse.FromString,
                )
        self.LogPhaseStatus = channel.unary_unary(
                '/com.qwak.build.v1.BuildAPI/LogPhaseStatus',
                request_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.LogPhaseStatusRequest.SerializeToString,
                response_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.LogPhaseStatusResponse.FromString,
                )
        self.GetPhaseStatuses = channel.unary_unary(
                '/com.qwak.build.v1.BuildAPI/GetPhaseStatuses',
                request_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.GetPhaseStatusesRequest.SerializeToString,
                response_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.GetPhaseStatusesResponse.FromString,
                )
        self.GetTagPath = channel.unary_unary(
                '/com.qwak.build.v1.BuildAPI/GetTagPath',
                request_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.GetTagPathRequest.SerializeToString,
                response_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.GetTagPathResponse.FromString,
                )
        self.RerunBuildFromExisting = channel.unary_unary(
                '/com.qwak.build.v1.BuildAPI/RerunBuildFromExisting',
                request_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.RerunBuildFromExistingRequest.SerializeToString,
                response_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.RerunBuildFromExistingResponse.FromString,
                )
        self.SaveFrameworkModels = channel.unary_unary(
                '/com.qwak.build.v1.BuildAPI/SaveFrameworkModels',
                request_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.SaveFrameworkModelsRequest.SerializeToString,
                response_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.SaveFrameworkModelsResponse.FromString,
                )
        self.GetBuildsArtifactsScanSummary = channel.unary_unary(
                '/com.qwak.build.v1.BuildAPI/GetBuildsArtifactsScanSummary',
                request_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.GetBuildsArtifactsScanSummaryRequest.SerializeToString,
                response_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.GetBuildsArtifactsScanSummaryResponse.FromString,
                )
        self.GetBuildImageDetails = channel.unary_unary(
                '/com.qwak.build.v1.BuildAPI/GetBuildImageDetails',
                request_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.GetBuildImageDetailsRequest.SerializeToString,
                response_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.GetBuildImageDetailsResponse.FromString,
                )
        self.UpdateBuildName = channel.unary_unary(
                '/com.qwak.build.v1.BuildAPI/UpdateBuildName',
                request_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.UpdateBuildNameRequest.SerializeToString,
                response_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.UpdateBuildNameResponse.FromString,
                )
        self.GetBuildsArtifactsScan = channel.unary_unary(
                '/com.qwak.build.v1.BuildAPI/GetBuildsArtifactsScan',
                request_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.GetBuildsArtifactsScanRequest.SerializeToString,
                response_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.GetBuildsArtifactsScanResponse.FromString,
                )


class BuildAPIServicer(object):
    """Missing associated documentation comment in .proto file."""

    def RegisterBuild(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateBuildStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterExperimentTracking(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterTags(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterModelSchema(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBuild(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListBuilds(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteBuild(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LogPhaseStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPhaseStatuses(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTagPath(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RerunBuildFromExisting(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SaveFrameworkModels(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBuildsArtifactsScanSummary(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBuildImageDetails(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateBuildName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBuildsArtifactsScan(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_BuildAPIServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'RegisterBuild': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterBuild,
                    request_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.RegisterBuildRequest.FromString,
                    response_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.RegisterBuildResponse.SerializeToString,
            ),
            'UpdateBuildStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateBuildStatus,
                    request_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.UpdateBuildStatusRequest.FromString,
                    response_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.UpdateBuildStatusResponse.SerializeToString,
            ),
            'RegisterExperimentTracking': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterExperimentTracking,
                    request_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.RegisterExperimentTrackingRequest.FromString,
                    response_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.RegisterExperimentTrackingResponse.SerializeToString,
            ),
            'RegisterTags': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterTags,
                    request_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.RegisterTagsRequest.FromString,
                    response_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.RegisterTagsResponse.SerializeToString,
            ),
            'RegisterModelSchema': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterModelSchema,
                    request_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.RegisterModelSchemaRequest.FromString,
                    response_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.RegisterModelSchemaResponse.SerializeToString,
            ),
            'GetBuild': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBuild,
                    request_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.GetBuildRequest.FromString,
                    response_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.GetBuildResponse.SerializeToString,
            ),
            'ListBuilds': grpc.unary_unary_rpc_method_handler(
                    servicer.ListBuilds,
                    request_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.ListBuildsRequest.FromString,
                    response_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.ListBuildsResponse.SerializeToString,
            ),
            'DeleteBuild': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteBuild,
                    request_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.DeleteBuildRequest.FromString,
                    response_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.DeleteBuildResponse.SerializeToString,
            ),
            'LogPhaseStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.LogPhaseStatus,
                    request_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.LogPhaseStatusRequest.FromString,
                    response_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.LogPhaseStatusResponse.SerializeToString,
            ),
            'GetPhaseStatuses': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPhaseStatuses,
                    request_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.GetPhaseStatusesRequest.FromString,
                    response_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.GetPhaseStatusesResponse.SerializeToString,
            ),
            'GetTagPath': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTagPath,
                    request_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.GetTagPathRequest.FromString,
                    response_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.GetTagPathResponse.SerializeToString,
            ),
            'RerunBuildFromExisting': grpc.unary_unary_rpc_method_handler(
                    servicer.RerunBuildFromExisting,
                    request_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.RerunBuildFromExistingRequest.FromString,
                    response_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.RerunBuildFromExistingResponse.SerializeToString,
            ),
            'SaveFrameworkModels': grpc.unary_unary_rpc_method_handler(
                    servicer.SaveFrameworkModels,
                    request_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.SaveFrameworkModelsRequest.FromString,
                    response_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.SaveFrameworkModelsResponse.SerializeToString,
            ),
            'GetBuildsArtifactsScanSummary': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBuildsArtifactsScanSummary,
                    request_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.GetBuildsArtifactsScanSummaryRequest.FromString,
                    response_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.GetBuildsArtifactsScanSummaryResponse.SerializeToString,
            ),
            'GetBuildImageDetails': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBuildImageDetails,
                    request_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.GetBuildImageDetailsRequest.FromString,
                    response_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.GetBuildImageDetailsResponse.SerializeToString,
            ),
            'UpdateBuildName': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateBuildName,
                    request_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.UpdateBuildNameRequest.FromString,
                    response_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.UpdateBuildNameResponse.SerializeToString,
            ),
            'GetBuildsArtifactsScan': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBuildsArtifactsScan,
                    request_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.GetBuildsArtifactsScanRequest.FromString,
                    response_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.GetBuildsArtifactsScanResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'com.qwak.build.v1.BuildAPI', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class BuildAPI(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def RegisterBuild(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.qwak.build.v1.BuildAPI/RegisterBuild',
            qwak_dot_build_dot_v1_dot_build__api__pb2.RegisterBuildRequest.SerializeToString,
            qwak_dot_build_dot_v1_dot_build__api__pb2.RegisterBuildResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateBuildStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.qwak.build.v1.BuildAPI/UpdateBuildStatus',
            qwak_dot_build_dot_v1_dot_build__api__pb2.UpdateBuildStatusRequest.SerializeToString,
            qwak_dot_build_dot_v1_dot_build__api__pb2.UpdateBuildStatusResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterExperimentTracking(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.qwak.build.v1.BuildAPI/RegisterExperimentTracking',
            qwak_dot_build_dot_v1_dot_build__api__pb2.RegisterExperimentTrackingRequest.SerializeToString,
            qwak_dot_build_dot_v1_dot_build__api__pb2.RegisterExperimentTrackingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterTags(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.qwak.build.v1.BuildAPI/RegisterTags',
            qwak_dot_build_dot_v1_dot_build__api__pb2.RegisterTagsRequest.SerializeToString,
            qwak_dot_build_dot_v1_dot_build__api__pb2.RegisterTagsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterModelSchema(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.qwak.build.v1.BuildAPI/RegisterModelSchema',
            qwak_dot_build_dot_v1_dot_build__api__pb2.RegisterModelSchemaRequest.SerializeToString,
            qwak_dot_build_dot_v1_dot_build__api__pb2.RegisterModelSchemaResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBuild(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.qwak.build.v1.BuildAPI/GetBuild',
            qwak_dot_build_dot_v1_dot_build__api__pb2.GetBuildRequest.SerializeToString,
            qwak_dot_build_dot_v1_dot_build__api__pb2.GetBuildResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListBuilds(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.qwak.build.v1.BuildAPI/ListBuilds',
            qwak_dot_build_dot_v1_dot_build__api__pb2.ListBuildsRequest.SerializeToString,
            qwak_dot_build_dot_v1_dot_build__api__pb2.ListBuildsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteBuild(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.qwak.build.v1.BuildAPI/DeleteBuild',
            qwak_dot_build_dot_v1_dot_build__api__pb2.DeleteBuildRequest.SerializeToString,
            qwak_dot_build_dot_v1_dot_build__api__pb2.DeleteBuildResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LogPhaseStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.qwak.build.v1.BuildAPI/LogPhaseStatus',
            qwak_dot_build_dot_v1_dot_build__api__pb2.LogPhaseStatusRequest.SerializeToString,
            qwak_dot_build_dot_v1_dot_build__api__pb2.LogPhaseStatusResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPhaseStatuses(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.qwak.build.v1.BuildAPI/GetPhaseStatuses',
            qwak_dot_build_dot_v1_dot_build__api__pb2.GetPhaseStatusesRequest.SerializeToString,
            qwak_dot_build_dot_v1_dot_build__api__pb2.GetPhaseStatusesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTagPath(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.qwak.build.v1.BuildAPI/GetTagPath',
            qwak_dot_build_dot_v1_dot_build__api__pb2.GetTagPathRequest.SerializeToString,
            qwak_dot_build_dot_v1_dot_build__api__pb2.GetTagPathResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RerunBuildFromExisting(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.qwak.build.v1.BuildAPI/RerunBuildFromExisting',
            qwak_dot_build_dot_v1_dot_build__api__pb2.RerunBuildFromExistingRequest.SerializeToString,
            qwak_dot_build_dot_v1_dot_build__api__pb2.RerunBuildFromExistingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SaveFrameworkModels(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.qwak.build.v1.BuildAPI/SaveFrameworkModels',
            qwak_dot_build_dot_v1_dot_build__api__pb2.SaveFrameworkModelsRequest.SerializeToString,
            qwak_dot_build_dot_v1_dot_build__api__pb2.SaveFrameworkModelsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBuildsArtifactsScanSummary(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.qwak.build.v1.BuildAPI/GetBuildsArtifactsScanSummary',
            qwak_dot_build_dot_v1_dot_build__api__pb2.GetBuildsArtifactsScanSummaryRequest.SerializeToString,
            qwak_dot_build_dot_v1_dot_build__api__pb2.GetBuildsArtifactsScanSummaryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBuildImageDetails(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.qwak.build.v1.BuildAPI/GetBuildImageDetails',
            qwak_dot_build_dot_v1_dot_build__api__pb2.GetBuildImageDetailsRequest.SerializeToString,
            qwak_dot_build_dot_v1_dot_build__api__pb2.GetBuildImageDetailsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateBuildName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.qwak.build.v1.BuildAPI/UpdateBuildName',
            qwak_dot_build_dot_v1_dot_build__api__pb2.UpdateBuildNameRequest.SerializeToString,
            qwak_dot_build_dot_v1_dot_build__api__pb2.UpdateBuildNameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBuildsArtifactsScan(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.qwak.build.v1.BuildAPI/GetBuildsArtifactsScan',
            qwak_dot_build_dot_v1_dot_build__api__pb2.GetBuildsArtifactsScanRequest.SerializeToString,
            qwak_dot_build_dot_v1_dot_build__api__pb2.GetBuildsArtifactsScanResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
